@@ -19,7 +19,7 @@ from scipy import interpolate
 import time
 
 # Import STIFMaps helper functions
-from misc import norm_pic, get_step
+from .misc import norm_pic, get_step
 
 #https://pytorch.org/vision/0.8/_modules/torchvision/models/alexnet.html
 class AlexNet(nn.Module):
